@@ -14,7 +14,7 @@ Reference: A. Tremols, P Cogolo, "Python Cookbook," p 302-305
 # Distributed under the terms of the Modified BSD License.
 
 import warnings
-warnings.warn("ipykernel.codeutil is deprecated. It has moved to ipyparallel.serialize", DeprecationWarning)
+warnings.warn("ipykernel.codeutil is deprecated since IPykernel 4.3.1. It has moved to ipyparallel.serialize", DeprecationWarning)
 
 import sys
 import types
@@ -35,4 +35,4 @@ def reduce_code(co):
         args.insert(1, co.co_kwonlyargcount)
     return code_ctor, tuple(args)
 
-copyreg.pickle(types.CodeType, reduce_code)
\ No newline at end of file
+copyreg.pickle(types.CodeType, reduce_code)
